{% if nav_item.children %}
  <a class="nav-title" > {{ nav_item.title }} </a>
  {% for nav_item in nav_item.children %}
    {% include "nav.html" %}
  {% endfor %}
{% else %}
    <li {% if nav_item.active %}class="active"{% endif %}>
      <a href="{{ nav_item.url | url }}" class="{{ class }}">
        {{ nav_item.title }}
      </a>
    </li>
{% endif %}